from django.conf import settings

from . import util

BLEACH_CLEAN_ACE_MODES = getattr(settings, "BLEACH_CLEAN_ACE_MODES", [
    "ace/mode/html",
    "ace/mode/django",
])
ALLOWED_HTML_TAGS = getattr(settings, "ALLOWED_HTML_TAGS", [tag for tag in util.HTML_TAGS if tag not in ('style', 'script')])
CLEANER_KWARGS = getattr(settings, "CLEANER_KWARGS", {
    "attributes": [
        "href",
        "src",
        "class",
        "style",
        "alt",
        "title",
        "width",
        "height",
        "id",
        "data",
    ],
    "strip": True,
    "strip_comments": True,
    "styles": [],
    "protocols": util.ALLOWED_PROTOCOLS,
})

try:
    from bleach.sanitizer import Cleaner

    _cleaner = Cleaner(tags=ALLOWED_HTML_TAGS, **CLEANER_KWARGS)
except ImportError:
    _cleaner = None

def clean_html(value):
    if _cleaner:
        return _cleaner.clean(value)
    
    raise ValueError("bleach.Cleaner not initialized, did you install bleach?")




HTML_TAGS = [
  'a',
  'abbr',
  'acronym',
  'address',
  'applet',
  'area',
  'article',
  'aside',
  'audio',
  'b',
  'base',
  'basefont',
  'bdi',
  'bdo',
  'bgsound',
  'big',
  'blink',
  'blockquote',
  'body',
  'br',
  'button',
  'canvas',
  'caption',
  'center',
  'circle',
  'cite',
  'clipPath',
  'code',
  'col',
  'colgroup',
  'command',
  'content',
  'data',
  'datalist',
  'dd',
  'defs',
  'del',
  'details',
  'dfn',
  'dialog',
  'dir',
  'div',
  'dl',
  'dt',
  'element',
  'ellipse',
  'em',
  'embed',
  'fieldset',
  'figcaption',
  'figure',
  'font',
  'footer',
  'foreignObject',
  'form',
  'frame',
  'frameset',
  'g',
  'h1',
  'h2',
  'h3',
  'h4',
  'h5',
  'h6',
  'head',
  'header',
  'hgroup',
  'hr',
  'html',
  'i',
  'iframe',
  'image',
  'img',
  'input',
  'ins',
  'isindex',
  'kbd',
  'keygen',
  'label',
  'legend',
  'li',
  'line',
  'linearGradient',
  'link',
  'listing',
  'main',
  'map',
  'mark',
  'marquee',
  'mask',
  'math',
  'menu',
  'menuitem',
  'meta',
  'meter',
  'multicol',
  'nav',
  'nextid',
  'nobr',
  'noembed',
  'noframes',
  'noscript',
  'object',
  'ol',
  'optgroup',
  'option',
  'output',
  'p',
  'param',
  'path',
  'pattern',
  'picture',
  'plaintext',
  'polygon',
  'polyline',
  'pre',
  'progress',
  'q',
  'radialGradient',
  'rb',
  'rbc',
  'rect',
  'rp',
  'rt',
  'rtc',
  'ruby',
  's',
  'samp',
  'script',
  'section',
  'select',
  'shadow',
  'slot',
  'small',
  'source',
  'spacer',
  'span',
  'stop',
  'strike',
  'strong',
  'style',
  'sub',
  'summary',
  'sup',
  'svg',
  'table',
  'tbody',
  'td',
  'template',
  'text',
  'textarea',
  'tfoot',
  'th',
  'thead',
  'time',
  'title',
  'tr',
  'track',
  'tspan',
  'tt',
  'u',
  'ul',
  'var',
  'video',
  'wbr',
  'xmp',
]

# code below from bleach module itself.
# all credit for this bit of code goes to the bleach team
# i sincerely want to thank them for their hard work
ALLOWED_PROTOCOLS = frozenset(("http", "https", "mailto"))




from wagtail import hooks
from django.utils.html import format_html
from django.templatetags.static import static

@hooks.register("insert_global_admin_css")
def global_admin_css():
    return format_html(
        '<link rel="stylesheet" href="{}">',
        static("wagtail_ace_editor/css/ace-editor-widget.css")
    )
